@@ -39,9 +39,9 @@
 #'
 #' @return An object containing errors, warnings, and notes.
 #' @template devtools
-#' @param document If `NA` and the package uses roxygen2, will
-#'   rerun [document()] prior to checking. Use `TRUE`
-#'   and `FALSE` to override this default.
+#' @param document By default (`NULL`) will document if your installed
+#'   roxygen2 version matches the version declared in the `DESCRIPTION`
+#'   file. Use `TRUE` or `FALSE` to override the default.
 #' @param build_args Additional arguments passed to `R CMD build`
 #' @param check_dir the directory in which the package is checked
 #'   compatibility. `args = "--output=/foo/bar"` can be used to change the
@@ -54,7 +54,7 @@
 #'   CRAN.
 #' @export
 check <- function(pkg = ".",
-                  document = NA,
+                  document = NULL,
                   build_args = NULL,
                   ...,
                   manual = FALSE,
@@ -76,7 +76,7 @@ check <- function(pkg = ".",
   save_all()
 
   if (!missing(cleanup)) {
-    warning("`cleanup` is deprecated", call. = FALSE)
+    lifecycle::deprecate_stop("1.11.0", "lifecycle::check(cleanup = )")
   }
 
   if (missing(error_on) && !interactive()) {
@@ -84,20 +84,19 @@ check <- function(pkg = ".",
   }
   error_on <- match.arg(error_on)
 
-  # document only if package uses roxygen, i.e. has RoxygenNote field
-  if (identical(document, NA)) {
-    document <- !is.null(pkg$roxygennote)
-  }
+  document <- document %||% can_document(pkg)
   if (document) {
+    if (!quiet) {
+      cat_rule("Documenting", col = "cyan", line = 2)
+    }
     document(pkg, quiet = quiet)
+    if (!quiet) {
+      cli::cat_line()
+    }
   }
 
   if (!quiet) {
-    cat_rule(
-      left = "Building",
-      right = pkg$package,
-      col = "cyan"
-    )
+    cat_rule("Building", col = "cyan", line = 2)
     show_env_vars(pkgbuild::compiler_flags(FALSE))
   }
 
@@ -117,7 +116,7 @@ check <- function(pkg = ".",
       vignettes = vignettes,
       ...
     )
-    on.exit(unlink(built_path), add = TRUE)
+    on.exit(file_delete(built_path), add = TRUE)
   })
 
   check_built(
@@ -136,6 +135,26 @@ check <- function(pkg = ".",
   )
 }
 
+can_document <- function(pkg) {
+  required <- pkg$roxygennote
+  if (is.null(required)) {
+    # Doesn't use roxygen2 at all
+    return(FALSE)
+  }
+
+  installed <- packageVersion("roxygen2")
+  if (required != installed) {
+    cli::cat_rule("Documenting", col = "red", line = 2)
+    cli::cli_inform(c(
+      i = "Installed roxygen2 version ({installed}) doesn't match required ({required})",
+      x = "{.fun check} will not re-document this package"
+    ))
+    FALSE
+  } else {
+    TRUE
+  }
+}
+
 #' @export
 #' @rdname check
 #' @param path Path to built package.
@@ -150,8 +169,9 @@ check <- function(pkg = ".",
 #'   `FALSE` (the default), check will proceed even if all suggested
 #'   packages aren't found.
 #' @param run_dont_test Sets `--run-donttest` so that tests surrounded in
-#'   \code{\\dontest\{\}} are also tested. This is important for CRAN
-#'   submission.
+#'   `\donttest{}` are also tested. When `cran = TRUE`, this only affects
+#'   R 3.6 and earlier; in R 4.0.0 code in `\donttest{}` is always run as
+#'   part of CRAN submission.
 #' @param manual If `FALSE`, don't build and check manual
 #'   (`--no-manual`).
 #' @param env_vars Environment variables set during `R CMD check`
@@ -167,7 +187,7 @@ check_built <- function(path = NULL, cran = TRUE,
   }
   error_on <- match.arg(error_on)
 
-  pkgname <- gsub("_.*?$", "", basename(path))
+  pkgname <- gsub("_.*?$", "", path_file(path))
 
   if (cran) {
     args <- c("--as-cran", args)
@@ -177,11 +197,7 @@ check_built <- function(path = NULL, cran = TRUE,
   }
 
   if (manual && !pkgbuild::has_latex()) {
-    message(
-      "pdflatex not found! Not building PDF manual or vignettes.\n",
-      "If you are planning to release this package, please run a check with ",
-      "manual and vignettes beforehand."
-    )
+    cli::cli_inform(c(x = "pdflatex not found! Not building PDF manual"))
     manual <- FALSE
   }
 
@@ -191,12 +207,8 @@ check_built <- function(path = NULL, cran = TRUE,
 
   env_vars <- check_env_vars(cran, remote, incoming, force_suggests, env_vars)
   if (!quiet) {
-    cat_rule(
-      left = "Checking",
-      right = pkgname,
-      col = "cyan"
-    )
-    show_env_vars(env_vars, trailing = FALSE)
+    cat_rule("Checking", col = "cyan", line = 2)
+    show_env_vars(env_vars)
   }
 
   withr::with_envvar(env_vars, action = "replace", {
@@ -224,15 +236,12 @@ check_env_vars <- function(cran = FALSE, remote = FALSE, incoming = remote,
 
 aspell_env_var <- function() {
   tryCatch({
-    utils::aspell(NULL)
+    utils::aspell(NULL, program = "aspell")
     c("_R_CHECK_CRAN_INCOMING_USE_ASPELL_" = "TRUE")
   }, error = function(e) character())
 }
 
-show_env_vars <- function(env_vars, trailing = TRUE) {
+show_env_vars <- function(env_vars) {
   cli::cat_line("Setting env vars:", col = "darkgrey")
   cat_bullet(paste0(format(names(env_vars)), ": ", unname(env_vars)), col = "darkgrey")
-  if (trailing) {
-    cat_rule(col = "cyan")
-  }
 }
